@@ -4,6 +4,7 @@ from getpass import getpass
 from hashlib import md5
 
 import click
+import requests
 
 from .clients import TidalClient
 from .config import Config
@@ -21,7 +22,9 @@ if not os.path.isdir(CACHE_DIR):
 
 @click.group(invoke_without_command=True)
 @click.option("-c", "--convert", metavar="CODEC", help="alac, mp3, flac, or ogg")
-@click.option("-u", "--urls", metavar="URLS", help="Url from Qobuz, Tidal, or Deezer")
+@click.option(
+    "-u", "--urls", metavar="URLS", help="Url from Qobuz, Tidal, SoundCloud, or Deezer"
+)
 @click.option(
     "-q",
     "--quality",
@@ -33,7 +36,7 @@ if not os.path.isdir(CACHE_DIR):
 @click.option("--debug", is_flag=True)
 @click.pass_context
 def cli(ctx, **kwargs):
-    """Streamrip: The all-in-one Qobuz, Tidal, and Deezer music downloader.
+    """Streamrip: The all-in-one Qobuz, Tidal, SoundCloud, and Deezer music downloader.
 
     To get started, try:
 
@@ -52,6 +55,22 @@ def cli(ctx, **kwargs):
 
     config = Config()
 
+    if config.session["check_for_updates"]:
+        from importlib import metadata
+
+        from packaging import version
+
+        r = requests.get("https://pypi.org/pypi/streamrip/json").json()
+        newest = r['info']['version']
+        if version.parse(metadata.version("streamrip")) < version.parse(newest):
+            click.secho(
+                "A new version of streamrip is available! "
+                "Run `pip3 install streamrip --upgrade` to update.",
+                fg="yellow",
+            )
+        else:
+            click.secho("streamrip is up-to-date!", fg='green')
+
     if kwargs["no_db"]:
         config.session["database"]["enabled"] = False
     if kwargs["convert"]:
@@ -113,7 +132,9 @@ def filter_discography(ctx, **kwargs):
 
 @cli.command()
 @click.option("-t", "--type", default="album", help="album, playlist, track, or artist")
-@click.option("-s", "--source", default="qobuz", help="qobuz, tidal, or deezer")
+@click.option(
+    "-s", "--source", default="qobuz", help="qobuz, tidal, soundcloud, or deezer"
+)
 @click.argument("QUERY", nargs=-1)
 @click.pass_context
 def search(ctx, **kwargs):
