@@ -37,7 +37,7 @@ class Config:
 
     defaults = {
         "qobuz": {
-            "quality": 2,
+            "quality": 3,
             "email": None,
             "password": None,
             "app_id": "",  # Avoid NoneType error
@@ -72,15 +72,16 @@ class Config:
             "non_studio_albums": False,
             "non_remaster": False,
         },
-        "downloads": {"folder": DOWNLOADS_DIR},
-        "metadata": {
-            "embed_cover": True,
-            "large_cover": True,
-            "default_comment": None,
-            "remove_extra_tags": False,
+        "downloads": {"folder": DOWNLOADS_DIR, "source_subdirectories": False},
+        "artwork": {
+            "embed": True,
+            "embed_size": "large",
+            "download_size": "original",
+            "keep_embedded_cover": False,
+            "keep_downloaded_cover": True,
         },
-        "keep_cover": True,
         "path_format": {"folder": FOLDER_FORMAT, "track": TRACK_FORMAT},
+        "check_for_updates": True,
     }
 
     def __init__(self, path: str = None):
