@@ -1,9 +1,9 @@
 import logging
-import sys
 import os
 import re
 import shutil
 import subprocess
+import sys
 from pprint import pformat, pprint
 from tempfile import gettempdir
 from typing import Any, Callable, Optional, Tuple, Union
@@ -335,6 +335,7 @@ class Track:
         """
 
         tracklist = cls._get_tracklist(album, client.source)
+        logger.debug(len(tracklist))
         track = tracklist[pos]
         meta = TrackMetadata(album=album, track=track, source=client.source)
         return cls(client=client, meta=meta, id=track["id"])
@@ -619,7 +620,7 @@ class Tracklist(list):
             size_ = os.path.getsize(cover_path)
             if size_ > FLAC_MAX_BLOCKSIZE:
                 raise TooLargeCoverArt(
-                    "Not suitable for Picture embed: {size_ * 10 ** 6}MB"
+                    f"Not suitable for Picture embed: {size_ / 10 ** 6} MB"
                 )
         elif cover is None:
             raise InvalidQuality(f"Quality {quality} not allowed")
@@ -742,13 +743,16 @@ class Album(Tracklist):
             else:
                 sampling_rate = None
 
+            resp["image"]["original"] = resp["image"]["large"].replace("600", "org")
+
             return {
                 "id": resp.get("id"),
                 "title": resp.get("title"),
                 "_artist": resp.get("artist") or resp.get("performer"),
-                "albumartist": resp.get("artist", {}).get("name"),
+                "albumartist": safe_get(resp, "artist", "name"),
                 "year": str(resp.get("release_date_original"))[:4],
                 "version": resp.get("version"),
+                "composer": safe_get(resp, "composer", "name"),
                 "release_type": resp.get("release_type", "album"),
                 "cover_urls": resp.get("image"),
                 "streamable": resp.get("streamable"),
@@ -758,6 +762,10 @@ class Album(Tracklist):
                 "bit_depth": resp.get("maximum_bit_depth"),
                 "sampling_rate": sampling_rate,
                 "tracktotal": resp.get("tracks_count"),
+                "description": resp.get("description"),
+                "disctotal": max(
+                    track.get("media_number", 1) for track in resp["tracks"]["items"]
+                ),
             }
         elif client.source == "tidal":
             return {
@@ -774,8 +782,11 @@ class Album(Tracklist):
                 "streamable": resp.get("allowStreaming"),
                 "quality": TIDAL_Q_MAP[resp.get("audioQuality")],
                 "bit_depth": 24 if resp.get("audioQuality") == "HI_RES" else 16,
-                "sampling_rate": 44100,  # always 44.1 kHz
+                "sampling_rate": 48000
+                if resp.get("audioQuality") == "HI_RES"
+                else 41000,
                 "tracktotal": resp.get("numberOfTracks"),
+                "disctotal": resp.get("numberOfVolumes"),
             }
         elif client.source == "deezer":
             if resp.get("release_date", False):
@@ -802,6 +813,7 @@ class Album(Tracklist):
                 "bit_depth": 16,
                 "sampling_rate": 44100,
                 "tracktotal": resp.get("track_total") or resp.get("nb_tracks"),
+                "disctotal": max(track["disk_number"] for track in resp["tracks"]),
             }
 
         raise InvalidSourceError(client.source)
@@ -877,51 +889,56 @@ class Album(Tracklist):
 
         self.download_message()
 
-        if os.path.isfile(cover_path):
-            logger.debug("Cover already downloaded: %s. Skipping", cover_path)
-        else:
-            click.secho("Downloading cover art", fg="magenta")
-            if kwargs.get("large_cover", True):
-                cover_url = self.cover_urls.get("large")
-                if self.client.source == "qobuz":
-                    tqdm_download(cover_url.replace("600", "org"), cover_path)
-                else:
-                    tqdm_download(cover_url, cover_path)
+        click.secho("Downloading cover art", fg="magenta")
+        download_cover_size = kwargs.get("download_cover_size", "original")
+        embed_cover_size = kwargs.get("embed_cover_size", "large")
+        if not os.path.isfile(cover_path):
+            if embed_cover_size not in self.cover_urls:
+                embed_cover_size = "large"
 
-                if os.path.getsize(cover_path) > FLAC_MAX_BLOCKSIZE:  # 16.7 MB
-                    click.secho(
-                        "Large cover is too large to embed, embedding small cover instead.",
-                        fg="yellow",
-                    )
-                    large_cover_path = cover_path.replace(".jpg", "_large") + ".jpg"
-                    shutil.move(cover_path, large_cover_path)
-                    tqdm_download(self.cover_urls["small"], cover_path)
-            else:
-                tqdm_download(self.cover_urls["small"], cover_path)
+            tqdm_download(self.cover_urls[embed_cover_size], cover_path)
+            if (
+                self.cover_urls.get(download_cover_size, embed_cover_size)
+                != embed_cover_size
+            ):
+                embed_cover_path = cover_path.replace(".jpg", "_embed.jpg")
+                shutil.move(cover_path, embed_cover_path)
+                tqdm_download(self.cover_urls[download_cover_size], cover_path)
 
         embed_cover = kwargs.get("embed_cover", True)  # embed by default
         if self.client.source != "deezer" and embed_cover:
             cover = self.get_cover_obj(cover_path, quality)
 
+        download_args = {
+            "quality": quality,
+            "parent_folder": folder,
+            "progress_bar": kwargs.get("progress_bar", True),
+            "database": database,
+            "track_format": kwargs.get("track_format", TRACK_FORMAT),
+        }
         for track in self:
             logger.debug("Downloading track to %s", folder)
-            track.download(
-                quality,
-                folder,
-                kwargs.get("progress_bar", True),
-                database=database,
-                track_format=kwargs.get("track_format", TRACK_FORMAT),
-            )
+            if self.disctotal > 1:
+                disc_folder = os.path.join(folder, f"Disc {track.meta.discnumber}")
+                download_args["parent_folder"] = disc_folder
+
+            track.download(**download_args)
+
             if kwargs.get("tag_tracks", True) and self.client.source != "deezer":
                 track.tag(cover=cover, embed_cover=embed_cover)
 
-        if not kwargs.get("keep_cover", True):
-            logger.debug(f"Removing cover at {cover_path}")
+        if not kwargs.get("keep_embedded_cover", True):
+            try:
+                os.remove(embed_cover_path)
+            except NameError:
+                pass
+
+        # TODO: fix this, bad solution
+        if not kwargs.get("keep_downloaded_cover", True):
             try:
                 os.remove(cover_path)
-                os.remove(large_cover_path)
-            except Exception as e:
-                logger.debug(e)
+            except NameError:
+                pass
 
         self.downloaded = True
 
@@ -943,13 +960,13 @@ class Album(Tracklist):
 
     def _get_formatted_folder(self, parent_folder: str, quality: int) -> str:
         if quality >= 2:
-            self.container = 'FLAC'
+            self.container = "FLAC"
         else:
             self.bit_depth = self.sampling_rate = None
-            if self.client.source == 'tidal':
-                self.container = 'AAC'
+            if self.client.source == "tidal":
+                self.container = "AAC"
             else:
-                self.container = 'MP3'
+                self.container = "MP3"
 
         formatted_folder = clean_format(self.folder_format, self._get_formatter())
 
@@ -1274,9 +1291,9 @@ class Artist(Tracklist):
         logger.debug(f"Length of tracklist {len(self)}")
         logger.debug(f"Filters: {filters}")
 
-        if 'repeats' in filters:
+        if "repeats" in filters:
             final = self._remove_repeats(bit_depth=max, sampling_rate=min)
-            filters = tuple(f for f in filters if f != 'repeats')
+            filters = tuple(f for f in filters if f != "repeats")
         else:
             final = self
 
